==> NISP-2.2-2-src.zip: nisp/sci_gateway/cpp/sci_polychaos_getanovaordco.cpp <==

// Copyright (C) 2008 - INRIA - Michael Baudin
// Copyright (C) 2009 - Digiteo - Michael Baudin
//
// This file must be used under the terms of the GNU Lesser General Public License license :
// http://www.gnu.org/copyleft/lesser.html

extern "C" {
#include "stack-c.h" 
#include "Scierror.h"
#include "localization.h"
#include "gw_nisp.h"
}


/* ==================================================================== */

#include "nisp_gwsupport.hxx" 
#include "nisp_PolynomialChaos_map.hxx" 


/* ==================================================================== */
// 
// polychaos_getanovaordco ( token , threshold , r )
//   prints out the anova ordered coefficients
// polychaos_getanovaordco ( token , threshold )
//   prints out the anova ordered coefficients
// polychaos_getanovaord ( token )
//   prints out the anovaco ordered coefficients
//
int sci_polychaos_getanovaordco (char *fname)
{
	int token;
	PolynomialChaos * pc = NULL;
	int r;
	double threshold;

	CheckRhs(1,3) ;
	CheckLhs(0,1) ;
	nisp_gettoken ( fname , 1 , &token );
	if ( (Rhs==2) | (Rhs==3) ) {
		nisp_GetOneDouble ( fname , 2 , &threshold );
	}
	if ( Rhs==3 ) {
		nisp_GetOneInteger ( fname , 3 , &r );
	}
	nisp_token2Polychaos ( fname , 1 , token , &pc );
	if (Rhs==1) {
		pc -> GetAnovaOrderedCoefficients ( );
	} else if (Rhs==2) {
		pc -> GetAnovaOrderedCoefficients ( threshold );
	} else if (Rhs==3) {
		pc -> GetAnovaOrderedCoefficients ( threshold , r );
	}
	nisp_CreateLhsInteger ( 1 , token );
	return 0;
}
/* ==================================================================== */

==> NISP-2.4.1-1-src.zip: nisp/sci_gateway/cpp/sci_polychaos_getanovaordco.cpp <==

// Copyright (C) 2008 - INRIA - Michael Baudin
// Copyright (C) 2009 - Digiteo - Michael Baudin
//
// This file must be used under the terms of the GNU Lesser General Public License license :
// http://www.gnu.org/copyleft/lesser.html

extern "C" {
#include "stack-c.h" 
#include "Scierror.h"
#include "localization.h"
#include "gw_nisp.h"
}


/* ==================================================================== */

#include "nisp_gwsupport.hxx" 
#include "nisp_PolynomialChaos_map.hxx" 


/* ==================================================================== */
// 
// polychaos_getanovaordco ( token , threshold , r )
//   prints out the anova ordered coefficients
// polychaos_getanovaordco ( token , threshold )
//   prints out the anova ordered coefficients
// polychaos_getanovaord ( token )
//   prints out the anovaco ordered coefficients
//
int sci_polychaos_getanovaordco (char *fname)
{
	int token;
	PolynomialChaos * pc = NULL;
	int r;
	double threshold;

	CheckRhs(1,3) ;
	CheckLhs(0,1) ;
	nispgw_gettoken ( fname , 1 , &token );
	if ( (Rhs==2) | (Rhs==3) ) {
		nispgw_GetOneDouble ( fname , 2 , &threshold );
	}
	if ( Rhs==3 ) {
		nispgw_GetOneInteger ( fname , 3 , &r );
	}
	nispgw_token2Polychaos ( fname , 1 , token , &pc );
	if (Rhs==1) {
		pc -> GetAnovaOrderedCoefficients ( );
	} else if (Rhs==2) {
		pc -> GetAnovaOrderedCoefficients ( threshold );
	} else if (Rhs==3) {
		pc -> GetAnovaOrderedCoefficients ( threshold , r );
	}
	nispgw_CreateLhsInteger ( 1 , token );
	return 0;
}
/* ==================================================================== */
